package conm.zhentao.util;

import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Component
public class TokenUtil {

    @Value("${jwt.secret}")
    private String jwtSecret;

    @Value("${jwt.expiration}")
    private Long jwtExpiration;

    @Autowired
    private RedisTemplate<String, String> redisTemplate;

    /**
     * 生成JWT token
     */
    public String generateJwtToken(Long userId) {
        Date now = new Date();
        Date expiryDate = new Date(now.getTime() + jwtExpiration);

        return Jwts.builder()
                .setSubject(String.valueOf(userId))
                .setIssuedAt(now)
                .setExpiration(expiryDate)
                .signWith(SignatureAlgorithm.HS512, jwtSecret)
                .compact();
    }

    /**
     * 生成Redis token
     */
    public String generateRedisToken(Long userId) {
        String token = UUID.randomUUID().toString().replace("-", "");
        // 存储到Redis，设置过期时间
        redisTemplate.opsForValue().set(
            "token:" + token,
            String.valueOf(userId),
            jwtExpiration,
            TimeUnit.MILLISECONDS
        );
        return token;
    }

    /**
     * 生成token（默认使用JWT）
     */
    public String generateToken(Long userId) {
        return "Bearer " + generateJwtToken(userId);
    }

    /**
     * 生成token（指定类型）
     */
    public String generateToken(Long userId, boolean useRedis) {
        if (useRedis) {
            return generateRedisToken(userId);
        }
        return "Bearer " + generateJwtToken(userId);
    }
} 